@@ -12,8 +12,6 @@ pub mod ansible_extra_vars_request;
 pub use self::ansible_extra_vars_request::AnsibleExtraVarsRequest;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
-pub mod ca_certs;
-pub use self::ca_certs::CaCerts;
 pub mod callback_token_auth_request;
 pub use self::callback_token_auth_request::CallbackTokenAuthRequest;
 pub mod callback_token_verification;
@@ -44,8 +42,6 @@ pub mod device_info;
 pub use self::device_info::DeviceInfo;
 pub mod device_info_request;
 pub use self::device_info_request::DeviceInfoRequest;
-pub mod device_key_pair;
-pub use self::device_key_pair::DeviceKeyPair;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
 pub mod device_state;
@@ -152,8 +148,6 @@ pub mod paginated_experiment_list;
 pub use self::paginated_experiment_list::PaginatedExperimentList;
 pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
-pub mod paginated_license_list;
-pub use self::paginated_license_list::PaginatedLicenseList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_device_list;
